==> react_image_annotate_ns_workflow-5.0.4.tgz: package/OCR/TaskFormLabel.js <==
import _objectSpread from "@babel/runtime/helpers/esm/objectSpread";
import WarningAmberIcon from "@mui/icons-material/WarningAmber";
import { IconButton } from "@mui/material";
import React from "react";
import { handleTooltipMessage } from "../Components/utils";
var labelStyle = {
  width: "90%",
  overflow: "hidden",
  wordBreak: "break-all",
  display: "inline-block",
  textOverflow: "ellipsis",
  whiteSpace: "nowrap"
};
function TaskFormLabel(_ref) {
  var display_label = _ref.display_label,
    isAstrick = _ref.isAstrick,
    _ref$isTooltip = _ref.isTooltip,
    isTooltip = _ref$isTooltip === void 0 ? true : _ref$isTooltip,
    isRequired = _ref.isRequired,
    invalid_show = _ref.invalid_show,
    invalid = _ref.invalid,
    handleInvalid = _ref.handleInvalid;
  return /*#__PURE__*/React.createElement("div", {
    className: "flex justify-betwwen"
  }, " ", /*#__PURE__*/React.createElement("label", {
    className: "title_input_box task_formlabel",
    style: _objectSpread({}, labelStyle),
    title: display_label
  }, display_label), isRequired ? /*#__PURE__*/React.createElement("span", {
    style: {
      color: "red"
    }
  }, isAstrick ? handleTooltipMessage({
    title: "Mandatory field to proceed with Save & Next",
    count: 2,
    isTooltip: isTooltip
  }) : handleTooltipMessage({
    title: "Mandatory field to proceed with Submit",
    count: 1,
    isTooltip: isTooltip
  })) : "", invalid_show && /*#__PURE__*/React.createElement(IconButton, {
    tabIndex: -1,
    style: {
      width: 22,
      height: 22
    },
    size: "small",
    variant: "outlined",
    onClick: function onClick() {
      handleInvalid(invalid);
    }
  }, /*#__PURE__*/React.createElement(WarningAmberIcon, {
    style: {
      color: invalid ? "#faad14" : "grey",
      marginTop: -8,
      width: 16,
      height: 16
    }
  })));
}
export default TaskFormLabel;

==> react_image_annotate_ns_workflow-5.0.8.tgz: package/OCR/TaskFormLabel.js <==
import _objectSpread from "@babel/runtime/helpers/esm/objectSpread";
import WarningAmberIcon from "@mui/icons-material/WarningAmber";
import { IconButton } from "@mui/material";
import React from "react";
import { handleTooltipMessage } from "../Components/utils";
var labelStyle = {
  width: "90%",
  overflow: "hidden",
  wordBreak: "break-all",
  display: "inline-block",
  textOverflow: "ellipsis",
  whiteSpace: "nowrap"
};
function TaskFormLabel(_ref) {
  var display_label = _ref.display_label,
    isAstrick = _ref.isAstrick,
    _ref$isTooltip = _ref.isTooltip,
    isTooltip = _ref$isTooltip === void 0 ? true : _ref$isTooltip,
    isRequired = _ref.isRequired,
    invalid_show = _ref.invalid_show,
    invalid = _ref.invalid,
    handleInvalid = _ref.handleInvalid;
  return /*#__PURE__*/React.createElement("div", {
    className: "flex justify-betwwen"
  }, " ", /*#__PURE__*/React.createElement("label", {
    className: "title_input_box task_formlabel",
    style: _objectSpread({}, labelStyle),
    title: display_label
  }, display_label), isRequired ? /*#__PURE__*/React.createElement("span", {
    style: {
      color: "red"
    }
  }, isAstrick ? handleTooltipMessage({
    title: "Mandatory field to proceed with Save & Next",
    count: 2,
    isTooltip: isTooltip
  }) : handleTooltipMessage({
    title: "Mandatory field to proceed with Submit",
    count: 1,
    isTooltip: isTooltip
  })) : "", invalid_show ? /*#__PURE__*/React.createElement(IconButton, {
    tabIndex: -1,
    style: {
      width: 22,
      height: 22
    },
    size: "small",
    variant: "outlined",
    onClick: function onClick() {
      handleInvalid(invalid);
    }
  }, /*#__PURE__*/React.createElement(WarningAmberIcon, {
    style: {
      color: invalid ? "#faad14" : "grey",
      marginTop: -8,
      width: 16,
      height: 16
    }
  })) : null);
}
export default TaskFormLabel;
